[][src]Module embedded_layout::align::horizontal

Horizontal alignment options

Horizontal alignment types must implement HorizontalAlignment.

Structs

Center

Center the objects horizontally

Left

Align the left edge of the object to the left edge of the reference

LeftToRight

Align the left edge of the object to the right edge of the reference, non-overlapping

NoAlignment

Keep the objects' horizontal alignment unchanged

Right

Align the right edge of the object to the right edge of the reference

RightToLeft

Align the right edge of the object to the left edge of the reference, non-overlapping