[][src]Trait embedded_layout::align::VerticalAlignment

pub trait VerticalAlignment: Alignment { }

Implement this trait for vertical alignment operations

Vertical alignment assumes lower coordinate values are higher up on the display.

This trait does not provide any functionality other than that of Alignment, but marks implementors to be used as vertical alignmenent operations.

For a list of available vertical alignments, see the vertical module.

Implementors

impl VerticalAlignment for Bottom[src]

impl VerticalAlignment for BottomToTop[src]

impl VerticalAlignment for Center[src]

impl VerticalAlignment for NoAlignment[src]

impl VerticalAlignment for Top[src]

impl VerticalAlignment for TopToBottom[src]

Loading content...