[][src]Module embedded_layout::align::vertical

Vertical alignment options

Vertical alignment types must implement VerticalAlignment.

Structs

Bottom

Align the bottom edge of the object to the bottom edge of the reference

BottomToTop

Align the bottom edge of the object to the top edge of the reference, non-overlapping

Center

Center the objects vertically

NoAlignment

Keep the objects' vertical alignment unchanged

Top

Align the top edge of the object to the top edge of the reference

TopToBottom

Align the top edge of the object to the bottom edge of the reference, non-overlapping